@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'ffi-gobject_introspection/i_base_info'
 require 'ffi-gobject_introspection/i_type_info'
 require 'ffi-gobject_introspection/i_arg_info'
@@ -7,7 +8,7 @@ module GObjectIntrospection
   # IFunctionInfo, ICallbackInfo or IVFuncInfo.
   class ICallableInfo < IBaseInfo
     def return_type
-      ITypeInfo.wrap(Lib.g_callable_info_get_return_type @gobj)
+      ITypeInfo.wrap Lib.g_callable_info_get_return_type(@gobj)
     end
 
     def caller_owns
@@ -18,12 +19,16 @@ module GObjectIntrospection
       Lib.g_callable_info_may_return_null @gobj
     end
 
+    def can_throw_gerror?
+      Lib.g_callable_info_can_throw_gerror @gobj
+    end
+
     def n_args
       Lib.g_callable_info_get_n_args @gobj
     end
 
-    def arg index
-      IArgInfo.wrap(Lib.g_callable_info_get_arg @gobj, index)
+    def arg(index)
+      IArgInfo.wrap Lib.g_callable_info_get_arg(@gobj, index)
     end
     ##
     build_array_method :args
@@ -31,5 +36,9 @@ module GObjectIntrospection
     def skip_return?
       Lib.g_callable_info_skip_return @gobj
     end
+
+    def instance_ownership_transfer
+      Lib.g_callable_info_get_instance_ownership_transfer @gobj
+    end
   end
 end
