@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module GObjectIntrospection
   # Wraps a GIEnumInfo struct if it represents an enum.
   # If it represents a flag, an IFlagsInfo object is used instead.
@@ -7,7 +8,7 @@ module GObjectIntrospection
     end
 
     def value(index)
-      IValueInfo.wrap(Lib.g_enum_info_get_value @gobj, index)
+      IValueInfo.wrap Lib.g_enum_info_get_value(@gobj, index)
     end
     ##
     build_array_method :values
@@ -17,7 +18,7 @@ module GObjectIntrospection
     end
 
     def get_method(index)
-      IFunctionInfo.wrap(Lib.g_enum_info_get_method @gobj, index)
+      IFunctionInfo.wrap Lib.g_enum_info_get_method(@gobj, index)
     end
 
     ##
