@@ -1,32 +1,38 @@
+# frozen_string_literal: true
 module GObjectIntrospection
-  # Wraps a GIFunctioInfo struct.
-  # Represents a function.
+  # Wraps a GIFunctionInfo struct.
+  # Represents a function or method.
   class IFunctionInfo < ICallableInfo
     def symbol
       Lib.g_function_info_get_symbol @gobj
     end
+
     def flags
       Lib.g_function_info_get_flags @gobj
     end
 
-    #TODO: Use some sort of bitfield
     def method?
-      flags & 1 != 0
+      flags[:is_method]
     end
+
     def constructor?
-      flags & 2 != 0
+      flags[:is_constructor]
     end
+
     def getter?
-      flags & 4 != 0
+      flags[:is_getter]
     end
+
     def setter?
-      flags & 8 != 0
+      flags[:is_setter]
     end
+
     def wraps_vfunc?
-      flags & 16 != 0
+      flags[:wraps_vfunc]
     end
+
     def throws?
-      flags & 32 != 0
+      flags[:throws]
     end
   end
 end
