@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module GObjectIntrospection
   # Wraps a GIStructInfo struct.
   # Represents a struct.
@@ -7,7 +8,7 @@ module GObjectIntrospection
     end
 
     def field(index)
-      IFieldInfo.wrap(Lib.g_struct_info_get_field @gobj, index)
+      IFieldInfo.wrap Lib.g_struct_info_get_field(@gobj, index)
     end
 
     ##
@@ -19,7 +20,7 @@ module GObjectIntrospection
     end
 
     def get_method(index)
-      IFunctionInfo.wrap(Lib.g_struct_info_get_method @gobj, index)
+      IFunctionInfo.wrap Lib.g_struct_info_get_method(@gobj, index)
     end
 
     ##
