@@ -2,8 +2,7 @@
 module GirFFI
   # Argument builder that does nothing. Implements the Null Object pattern.
   class NullArgumentBuilder
-    def initialize(*)
-    end
+    def initialize(*); end
 
     def pre_conversion
       []
