@@ -3,8 +3,7 @@ module GirFFI
   module Builders
     # Implements a blank return value matching ReturnValueBuilder's interface.
     class NullReturnValueBuilder
-      def initialize
-      end
+      def initialize; end
 
       def array_length_idx
         -1
