@@ -1,4 +1,6 @@
+# frozen_string_literal: true
 require 'gir_ffi/builders/object_builder'
+require 'gir_ffi/unintrospectable_signal_info'
 
 module GirFFI
   module Builders
@@ -6,10 +8,6 @@ module GirFFI
     # which no data is found in the GIR. Typically, these are created to
     # cast objects returned by a function that returns an interface.
     class UnintrospectableBuilder < ObjectBuilder
-      def instantiate_class
-        setup_class unless already_set_up
-      end
-
       def klass
         @klass ||= TypeBuilder::CACHE[target_gtype] ||= Class.new(superclass)
       end
@@ -20,14 +18,15 @@ module GirFFI
         setup_interfaces
       end
 
-      def setup_instance_method _method
+      def setup_instance_method(_method)
         false
       end
 
-      private
-
-      def signal_definers
-        info.interfaces
+      def find_signal(signal_name)
+        info = super
+        return info if info
+        signal_id = GObject.signal_lookup signal_name, target_gtype
+        return UnintrospectableSignalInfo.new(signal_id) if signal_id > 0
       end
     end
   end
