@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'gir_ffi/builders/field_builder'
 
 module GirFFI
@@ -34,12 +35,6 @@ module GirFFI
         fields.map(&:layout_specification).flatten(1)
       end
 
-      def setup_field_accessors
-        fields.each do |finfo|
-          FieldBuilder.new(finfo).build
-        end
-      end
-
       def klass
         @klass ||= get_or_define_class namespace_module, @classname, superclass
       end
