@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'gir_ffi/info_ext/full_type_name'
 require 'gir_ffi/info_ext/i_arg_info'
 require 'gir_ffi/info_ext/i_callable_info'
@@ -8,6 +9,7 @@ require 'gir_ffi/info_ext/i_property_info'
 require 'gir_ffi/info_ext/i_registered_type_info'
 require 'gir_ffi/info_ext/i_signal_info'
 require 'gir_ffi/info_ext/i_type_info'
+require 'gir_ffi/info_ext/i_unresolved_info'
 require 'gir_ffi/info_ext/i_vfunc_info'
 require 'gir_ffi/info_ext/safe_constant_name'
 require 'gir_ffi/info_ext/safe_function_name'
