@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module GirFFI
   # Helper class for storing objects for later retrieval. Used to store user
   # data arguments.
@@ -7,6 +8,7 @@ module GirFFI
     end
 
     def store(obj)
+      return FFI::Pointer::NULL if obj.nil?
       # FIXME: Don't use object_id!
       key = obj.object_id
       @store[key] = obj
