@@ -61,41 +61,3 @@ module BaseTestExtensions
 end
 
 Minitest::Test.send :include, BaseTestExtensions
-
-# Provide methods needed for integration with mutant
-module ForMutant
-  # Mark the current test class as covering the given expression.
-  def cover(expression)
-    @expression = expression
-  end
-
-  # Return the currently set covering expression.
-  def covering
-    defined?(@expression) && @expression
-  end
-
-  # Return the cover expression, but raise an exception if it is not defined.
-  # This is the method used by mutant to fetch the coverage information.
-  def cover_expression
-    raise "Cover expression for #{self} is not specified" unless @expression
-    @expression
-  end
-end
-
-Minitest::Test.send :extend, ForMutant
-
-def cover_expression_for(cls)
-  full_stack = cls.describe_stack.dup << cls
-  full_stack.reverse_each do |level|
-    return level.covering if level.covering
-    return level.desc.to_s if level.desc.is_a? Module
-  end
-  full_stack.first.desc.to_s
-end
-
-# Override describe to automatically set cover information
-def describe(desc, *additional_desc, &block)
-  super.tap do |cls|
-    cls.cover cover_expression_for(cls) unless cls.covering
-  end
-end
